# Generated by Django 3.0.11 on 2021-02-02 12:57

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('qrtoolkit_core', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='qrcode',
            name='department',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='qrcodes', to='qrtoolkit_core.Department'),
        ),
        migrations.AlterField(
            model_name='qrcode',
            name='uuid',
            field=models.UUIDField(default=uuid.uuid4),
        ),
    ]
